Crate type_props

Crate type_props 

Type properties for basic data types.

This crate includes some marker traits, type properties, and miscellaneous data-handling traits which were previously part of https://docs.rs/memapi2.

Re-exports

pub use crate::marker::SizeMeta;
pub use crate::marker::Thin;
pub use crate::marker::UnsizedCopy;
pub use crate::type_props::PtrProps;
pub use crate::type_props::SizedProps;
pub use crate::type_props::VarSizedStruct;
pub use crate::type_props::VarSized;
pub use crate::consts::USIZE_HIGH_BIT;
pub use crate::consts::USIZE_MAX_NO_HIGH_BIT;

Modules

consts
Some minimal, useful constants.
helpers
Assorted helpers.
marker
Marker traits.
type_props
Sized type properties as constants and property getters for pointers.